==> jc-1.4.0.tar.gz: polyglot/lex/IntegerLiteral.h <==
// public class polyglot.lex.IntegerLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d4e49f78a791d2af polyglot_lex_IntegerLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_NumericLiteral

#include "polyglot/lex/NumericLiteral.h"

#ifndef _JC_polyglot_lex_IntegerLiteral_H_
#define _JC_polyglot_lex_IntegerLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_IntegerLiteral$sub_refs	_jc_polyglot_lex_IntegerLiteral$sub_refs;
typedef struct _jc_polyglot_lex_IntegerLiteral$sub_nonrefs	_jc_polyglot_lex_IntegerLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_IntegerLiteral$refs	_jc_polyglot_lex_IntegerLiteral$refs;
typedef struct _jc_polyglot_lex_IntegerLiteral$nonrefs	_jc_polyglot_lex_IntegerLiteral$nonrefs;
typedef struct _jc_polyglot_lex_IntegerLiteral$object	_jc_polyglot_lex_IntegerLiteral$object;

typedef const struct _jc_polyglot_lex_IntegerLiteral$vmethods	_jc_polyglot_lex_IntegerLiteral$vmethods;
typedef const struct _jc_polyglot_lex_IntegerLiteral$vtable	_jc_polyglot_lex_IntegerLiteral$vtable;
typedef const struct _jc_polyglot_lex_IntegerLiteral$vtype	_jc_polyglot_lex_IntegerLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_IntegerLiteral$method$_init$8bfdbb979d628762(_jc_env *, struct _jc_polyglot_lex_IntegerLiteral$object *, struct _jc_polyglot_util_Position$object *, jint, jint);

// Virtual methods structure
struct _jc_polyglot_lex_IntegerLiteral$vmethods {
};

// Vtable
struct _jc_polyglot_lex_IntegerLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
	_jc_polyglot_lex_IntegerLiteral$vmethods	polyglot_lex_IntegerLiteral;
};

// Vtype
struct _jc_polyglot_lex_IntegerLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_IntegerLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_IntegerLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_IntegerLiteral$refs {
    _jc_polyglot_lex_IntegerLiteral$sub_refs	polyglot_lex_IntegerLiteral;
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_IntegerLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_IntegerLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_IntegerLiteral$sub_nonrefs	polyglot_lex_IntegerLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_IntegerLiteral$object {
	_jc_polyglot_lex_IntegerLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_IntegerLiteral$vtype	*vtype;
	_jc_polyglot_lex_IntegerLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_IntegerLiteral$vtype _jc_polyglot_lex_IntegerLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_IntegerLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_IntegerLiteral$class_object;

#endif	/* _JC_polyglot_lex_IntegerLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/IntegerLiteral.h <==
// public class polyglot.lex.IntegerLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d4e49f78a791d2af polyglot_lex_IntegerLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_NumericLiteral

#include "polyglot/lex/NumericLiteral.h"

#ifndef _JC_polyglot_lex_IntegerLiteral_H_
#define _JC_polyglot_lex_IntegerLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_IntegerLiteral$sub_refs	_jc_polyglot_lex_IntegerLiteral$sub_refs;
typedef struct _jc_polyglot_lex_IntegerLiteral$sub_nonrefs	_jc_polyglot_lex_IntegerLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_IntegerLiteral$refs	_jc_polyglot_lex_IntegerLiteral$refs;
typedef struct _jc_polyglot_lex_IntegerLiteral$nonrefs	_jc_polyglot_lex_IntegerLiteral$nonrefs;
typedef struct _jc_polyglot_lex_IntegerLiteral$object	_jc_polyglot_lex_IntegerLiteral$object;

typedef const struct _jc_polyglot_lex_IntegerLiteral$vmethods	_jc_polyglot_lex_IntegerLiteral$vmethods;
typedef const struct _jc_polyglot_lex_IntegerLiteral$vtable	_jc_polyglot_lex_IntegerLiteral$vtable;
typedef const struct _jc_polyglot_lex_IntegerLiteral$vtype	_jc_polyglot_lex_IntegerLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_IntegerLiteral$method$_init$8bfdbb979d628762(_jc_env *, struct _jc_polyglot_lex_IntegerLiteral$object *, struct _jc_polyglot_util_Position$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_lex_IntegerLiteral$vmethods {
};

// Vtable
struct _jc_polyglot_lex_IntegerLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
	_jc_polyglot_lex_IntegerLiteral$vmethods	polyglot_lex_IntegerLiteral;
};

// Vtype
struct _jc_polyglot_lex_IntegerLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_IntegerLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_IntegerLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_IntegerLiteral$refs {
    _jc_polyglot_lex_IntegerLiteral$sub_refs	polyglot_lex_IntegerLiteral;
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_IntegerLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_IntegerLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_IntegerLiteral$sub_nonrefs	polyglot_lex_IntegerLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_IntegerLiteral$object {
	_jc_polyglot_lex_IntegerLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_IntegerLiteral$vtype	*vtype;
	_jc_polyglot_lex_IntegerLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_IntegerLiteral$vtype _jc_polyglot_lex_IntegerLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_IntegerLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_IntegerLiteral$class_object;

#endif	/* _JC_polyglot_lex_IntegerLiteral_H_ */
